<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>ToggleBlockVisibility</name>
    <message>
        <location filename="../ToggleBlockVisibilityInit.js" line="+2"/>
        <source>&amp;Toggle Visibility</source>
        <translation>&amp;Basculer la visibilité</translation>
    </message>
</context>
</TS>
